﻿<%@ Application Language="C#" %>

<script RunAt="server">
    /// <summary>
    /// هنگامی رخ میدهد که اپلیکیشن استارت میشود
    /// کارهایی را که میخواهیم در هنگام استارت اپلیکیشن که خود وبسایت هست انجام دهیم در این ایونت قرار میدهیم
    ///در این مثال میخواهیم یک متغیر از جنس اپلیکیشن ایجاد نمائیم 
    /// که این متغیر تعداد کاربران آنلاین را نگه داری میکند
    /// این متغیر را با مقدار 0 مقدار دهی اولیه نموده ایم
    /// متعیر اپلیکیشن متغیری برای تمامی کاربران و برای تمامی صفحات سایت میباشد
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void Application_Start(object sender, EventArgs e)
    {
        Application.Lock();
        Application["OnLineUserCount"] = 0;
        Application.UnLock();

    }

    /// <summary>
    /// هنگامی اجرا میشود که یک سشن ایجاد گردد
    /// در این مثال متغییر اپلیکیشنی که در ایونت بالا ساختیم را یک واحد به آن اضافه میکنیم
    /// بدین ترتیب هر کاربر که به سایت اضافه میشود این متغیر یک واحد افزوده میگردد
    /// متعیر سشن متغییری برای یک کاربر و برای تمامی صفحات سایت میباشد
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void Session_Start(object sender, EventArgs e)
    {
        Application.Lock();
        Application["OnLineUserCount"] =
            Convert.ToInt64(Application["OnLineUserCount"]) + 1;
        Application.UnLock();

    }
    /// <summary>
    /// هنگامی اجرا میشود که یک سشن یه پایان برسد
    /// در این مثال متغییر اپلیکیشنی که در ایونت بالا ساختیم را یک واحد از آن کم میکنیم
    /// بدین ترتیب هر کاربر که از سایت خارج میشود این متغیر یک واحد ز آن کم میگردد
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void Session_End(object sender, EventArgs e)
    {
        Application.Lock();
        Application["OnLineUserCount"] =
            Convert.ToInt64(Application["OnLineUserCount"]) - 1;
        Application.UnLock();

    }
    /// <summary>
    /// هنگامی اجرا میشود که برنامه با خطا مواجه گردد
    /// در این مثال اگر خطای سیستمی - دات نتی  یا وب سروری رخ دهد آن را لاگ میکنیم
    /// اگر در برنامه ایونت پیج ارور باشیم میتوانیم خطا را در هر صفحه و درایونت پیج ارور مربوط به همان صفحه درج کنیم
    /// در نهایت و اگر ایونت پیج ارور مستقل برای هر صفحه ننویسیم و یا بنویسیم و کلیر نکنیم خطا میاد اینجا که ببینه چی کار باید بکنه
    /// اگر همینجا هم کلیر ارور رو بنویسیم که همینجا تموم میشه اگر نه میره تو وب دات کانفیگ در قسمت تنظیمات ارور و از اونجا کنترل میشه
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void Application_Error(object sender, EventArgs e)
    {
        //توسط رپر ذیل پک میکنیم آیا خطا ریشه داشته اگر داشته باشه ریشه را از مراحل قبل بدست میاوریم
        //رپر ذیل در اصل سه شرط ذیل را مورد بررسی قرار میدهد
        //شرط اول تنها وقتی اتفاق میفته که اپلیکیشن نال باشه
        //ولی تلویحا اون رو هم مینویسیم
        if ((Server != null) &&
        (Server.GetLastError() != null) &&
        (Server.GetLastError().GetBaseException() != null))
        {
            //خطا را برابر با ابتدایی ترین خطا قرار میدهیم
            System.Exception ex =
                Server.GetLastError().GetBaseException();

            //توسط رشته ذیل تاریخ و ساعت بروز خطا آدرس فیزیکی و آی پی کاربر ایاد کننده خطا را نگهداری میکنیم
            string strErrorMessage =
                string.Format("{0} Time:{1:yyyy/mm/dd - hh:mm:ss},Path:{2},User IP{3}",
                ex.Message,
                System.DateTime.Now,
                Request.PhysicalPath,
                Request.UserHostAddress);

            //قفل نمودن اپلیکیشن
            Application.Lock();

            //ایجاد یک شی از کلاس استریم رایتر
            System.IO.StreamWriter oStreamWriter = null;

            //بدنه ترای کج
            try
            {
                
                //خطا را توسط آدرس نسبی و تیدیل آن به آدرس فیزیکی  با شی ایجاد شده از استریم رایتر لاگ میکنیم
                string strApplicationPath =
                    "~/App_Data/Log/Application.log";

                string strApplicationPathName =
                    Server.MapPath(strApplicationPath);

                oStreamWriter =
                    new System.IO.StreamWriter(strApplicationPathName, true, System.Text.Encoding.UTF8);

                oStreamWriter.WriteLine(strErrorMessage);

            }
            catch
            {
                //!!! :( هر چه بگندد نمکش میزنند وای بروزی که بگندد نمک !!! :)
            }

            finally
            {
                //بررسی باز بودن یا نبودن شی استریم و بستن آن در صورت باز بودن
                if (oStreamWriter != null)
                {
                    oStreamWriter.Dispose();
                    oStreamWriter = null;
                }
            }
            
            //باز کردن اپلیکیشن
            Application.UnLock();
        }

    }
    /// <summary>
    /// هنگامی اجرا میشودکه برنامه به انتها برسد
    /// منظور از برنامه یااپلیکیشن خود وبسایت میباشد
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void Application_End(object sender, EventArgs e)
    {
        //  Code that runs on application shutdown

    }
        
   
    /// <summary>
   /// جهت اطلاع
   /// متعیر ویو استایت متغیری برای یک کاربر و برای همان صفحه ار سایت میباشد
   /// </summary>
   
       
</script>
