﻿using System;
using System.Collections.Generic;

using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class UserControls_Login : System.Web.UI.UserControl
{
    protected void Page_Load(object sender, System.EventArgs e)
    {
        divPageMessage.Visible = false;

        //اگر کاربر لاگین نکرده باشد با توجه به تنظیمات وب دات کانقیگ به این صفحه هدایت میشود
        //در هنگام لود شدن این صفحه اگر کاربر درخواست صفحه ای را داده باشد که نیاز به لاگین دارد
        //توسط دستور ذیل آدرس صفحه ای که کاربر درخواست کرده است را بدست میاوریم
        string strReturnUrl = Request.Params["ReturnUrl"];

        if (string.IsNullOrEmpty(strReturnUrl) == false)
        {
            //یک متغیر رشته ای ایجاد میکنیم و فایل نیم آدرس رو بدست میاوریم
            string strfileName =
                System.IO.Path.GetFileName(strReturnUrl);
            //یک پیغام خطا ایحاد میکنیم و به کاربر نمایش میدهیم که در خواست صفحه ای را نموده که امن هست
            string strErrorMessage =
                string.Format(Resources.Messages.ErrorMessage018, strfileName);
            divPageMessage.Visible = true;
            litPageMessage.Text = strErrorMessage;
        }


        if (Page.IsPostBack == false)
        {
            Initialize();
        }
    }

    /// <summary>
    /// در این متد چک میکنیم آیا فیلد ها پر شده است یا خیر
    /// </summary>
    private void Initialize()
    {

        // تکميل فيلد {0} الزامی است
        rfvUsername.ErrorMessage =
            string.Format(Resources.Messages.ErrorMessage002, Resources.Captions.Username);

        // تکميل فيلد {0} الزامی است
        rfvPassword.ErrorMessage =
            string.Format(Resources.Messages.ErrorMessage002, Resources.Captions.Password);


    }

    /// <summary>
    /// ایونت کلیک روی دکمه سابمیت
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSubmit_Click(object sender, EventArgs e)
    {
        //چک نمودن ولید بودن صفحه
        if (Page.IsValid)
        {
            //ایجاد یک شی از کلاس دیتا ست.یوزر تیبل آداپتر
            DAL.MyDataSet.UsersDataTable oUserDataTable = new DAL.MyDataSet.UsersDataTable();

            //ایجاد یک شی از کلاس دیتا ست تیبل آدابتر دات یوزر تیبل  آداپتر
            DAL.MyDataSetTableAdapters.UsersTableAdapter oUserTableAdapter =
                new DAL.MyDataSetTableAdapters.UsersTableAdapter();

            //پر نمودن شی ساخته شده از تیبل آداپتر با شی ساخته شده از دیتا تیبل با متد مربوطه
            oUserTableAdapter.FillByUsername(oUserDataTable, txtUsername.Text);

            //بررسی اینکه آیا کاربری وجود داشته است یا خیر
            if (oUserDataTable.Count != 1)
            {
                string strErrorMessage = Resources.Messages.ErrorMessage013;
                DisplayErrorMessage(strErrorMessage);
                return;
            }

            //ایجاد یک شی از کلاس دیتاست . یوزر رو و مقدار دهی آن توسط شی ساخته شده از دیتا تیبل
            DAL.MyDataSet.UsersRow oUserRow = oUserDataTable[0];

            //بررسی یکسان بودن گذرواژه
            if (string.Compare(oUserRow.Password.Trim(), txtPassword.Text.Trim(), false) != 0)
            {
                string strErrorMessage = Resources.Messages.ErrorMessage013;
                DisplayErrorMessage(strErrorMessage);
                return;
            }

            //بررسی فعال بودن کاربر
            if (oUserRow.IsUserActive == false)
            {
                string strErrorMessage = string.Format(Resources.Messages.ErrorMessage014, txtUsername.Text);
                DisplayErrorMessage(strErrorMessage);
                return;
            }


            //ایجاد متغیر های سشن
            Session["UserID"] = oUserRow.UserID;
            Session["Username"] = oUserRow.Username;
            //توسط دستور ذیل کاربر را به نوعی ساین این میکنیم و به صقحه لاگین هدایت میکنیم
            System.Web.Security.FormsAuthentication.RedirectFromLoginPage(oUserRow.Username, false);

        }
    }

    /// <summary>
    /// متد های نمایش پیام
    /// </summary>
    /// <param name="message"></param>
    protected virtual void DisplayErrorMessage(string message)
    {
        divPageMessage.Visible = true;
        litPageMessage.Text =
            string.Format("<div class ='error'>{0}</div>", message);
    }

    protected virtual void DisplayWarningMessage(string message)
    {
        divPageMessage.Visible = true;
        litPageMessage.Text =
            string.Format("<div class ='warning'>{0}</div>", message);
    }

    protected virtual void DisplayInformationMessage(string message)
    {
        divPageMessage.Visible = true;
        litPageMessage.Text =
            string.Format("<div class ='information'>{0}</div>", message);
    }
    protected void btnCancel_Click(object sender, EventArgs e)
    {

    }
}