﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class UserControls_WebUserControl : System.Web.UI.UserControl
{
    protected void Page_Load(object sender, System.EventArgs e)
    {

        if (Page.IsPostBack == false)
        {
            Initialize();
        }
    }

    /// <summary>
    /// در این متد چک میکنیم آیا فیلد ها پر شده است یا خیر
    /// </summary>
    private void Initialize()
    {

        // تکميل فيلد {0} الزامی است
        rfvUsername.ErrorMessage =
            string.Format(Resources.Messages.ErrorMessage002, Resources.Captions.Username);

        // تکميل فيلد {0} الزامی است
        rfvPassword.ErrorMessage =
            string.Format(Resources.Messages.ErrorMessage002, Resources.Captions.Password);

        // تکميل فيلد {0} الزامی است
        rfvConfirmPassword.ErrorMessage =
            string.Format(Resources.Messages.ErrorMessage002, Resources.Captions.ConfirmPassword);

        // تکميل فيلد {0} الزامی است
        rfvEmail.ErrorMessage =
            string.Format(Resources.Messages.ErrorMessage002, Resources.Captions.Email);

    }

    /// <summary>
    /// متد بررسی نام کاربری و ایمیل کاربر هنگام ثبت نام
    /// این متد چهار ورودی دارد
    /// به ترتیب
    /// دیتا تیبل - تیبل آداپتر - نام کاربری و رایانامه
    /// این متد یک رشته استرینگ حاوی پیام خطا برمیگرداند
    /// در صورتی که مشکل هنگام ثبت نام وجود نداشته باشد مقدار رشته خالی است
    /// </summary>
    /// <param name="oUserDataTable"></param>
    /// <param name="oUserTableAdapter"></param>
    /// <param name="username"></param>
    /// <param name="email"></param>
    /// <returns></returns>
    private string CheckRegistration(DAL.MyDataSet.UsersDataTable oUserDataTable,
        DAL.MyDataSetTableAdapters.UsersTableAdapter oUserTableAdapter,
        string username,string email)
    {
        //ایجاد یک پیام خطا
        string strErrorMessage = string.Empty;

        //پر نمودن شی ورودی تیبل آدابتر با شی ورودی دیتا تیبل و نام کاربری توسط متد مربوطه
        oUserTableAdapter.FillByUsername(oUserDataTable, username);

        //بررسی اینکه آیا نام کاربری وارد شده در سیستم وجود دارد یا خیر
        if (oUserDataTable.Count !=0)
        {
            if (string.IsNullOrEmpty(strErrorMessage)==false)
            {
                strErrorMessage += "<br/>";
            }

            strErrorMessage += Resources.Messages.ErrorMessage015;

        }

        //پر نمودن شی ورودی تیبل آدابتر با شی ورودی دیتا تیبل و رایانامه توسط متد مربوطه
        oUserTableAdapter.FillByEmail(oUserDataTable, email);

        //بررسی اینکه آیا رایانامه وارد شده در سیستم وجود دارد یا خیر
        if (oUserDataTable.Count!=0)
        {
            if (string.IsNullOrEmpty(strErrorMessage)==false)
            {
                strErrorMessage += "<br/>";
            }

            strErrorMessage += Resources.Messages.ErrorMessage016;
        }

        //ارسال پیام خطا ایجاد شده به عنوان خروجی متد
        return strErrorMessage;
    }

    /// <summary>
    /// ایونت کلیک دکمه سابمیت
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSubmit_Click(object sender, EventArgs e)
    {
        //ایجاد یک شی از دیتا تیبل
        DAL.MyDataSet.UsersDataTable oUserDataTable = new DAL.MyDataSet.UsersDataTable();

        //ایجاد یک شی از تیبل آداپتر
        DAL.MyDataSetTableAdapters.UsersTableAdapter oUserTableAdapter =
            new DAL.MyDataSetTableAdapters.UsersTableAdapter();

        //ایجاد یک پیام خطا از جنس استرینگ و مقدار دهی آن با متد بررسی نام کاربری و ایمیل
        string strErrorMessage=
        CheckRegistration(oUserDataTable, oUserTableAdapter, txtUsername.Text, txtEmail.Text);

        //بررسی مقدار خروجی متد 
        if (string.IsNullOrEmpty(strErrorMessage)==false)
        {
            DisplayErrorMessage(strErrorMessage);
            return;
        }

        //ایجاد یک شی از یوزر رو و مقدار دهی آن با یک خط جدید
        DAL.MyDataSet.UsersRow oUserRow = oUserDataTable.NewUsersRow();

        //مقدار دهی بقیه فیلد های جدول یوزرز در دیتا بیس با استفاده از شی یوزر رو
        oUserRow.Username = txtUsername.Text.ToLower();
        oUserRow.Password = txtPassword.Text;
        oUserRow.Email = txtEmail.Text.ToLower();
        //فعال یا غیر فعال نمودن کاربر در هنگام ثبت نام
        oUserRow.IsUserActive = true;

        //افزودن خط جدید ایجاد شده به شی دیتا تیبل
        oUserDataTable.AddUsersRow(oUserRow);

        //افزودن دیتا تیبل ایجاد شده به تیبل آداپتر
        oUserTableAdapter.Update(oUserDataTable);

        //نمایش پیام موفقیت در ثبت نام
        string strInformationMessage =
            Resources.Messages.InformationMessage004;
        litPageMessage.Text = strInformationMessage;

    }

    /// <summary>
    /// متد های نمایش پیام
    /// </summary>
    /// <param name="message"></param>
    protected virtual void DisplayErrorMessage(string message)
    {
        divPageMessage.Visible = true;
        litPageMessage.Text =
            string.Format("<div class ='error'>{0}</div>", message);
    }

    protected virtual void DisplayWarningMessage(string message)
    {
        divPageMessage.Visible = true;
        litPageMessage.Text =
            string.Format("<div class ='warning'>{0}</div>", message);
    }

    protected virtual void DisplayInformationMessage(string message)
    {
        divPageMessage.Visible = true;
        litPageMessage.Text =
            string.Format("<div class ='information'>{0}</div>", message);
    }
}